@@ -230,11 +230,16 @@ impl ElectrsD {
             nix::sys::signal::SIGUSR1,
         )?)
     }
+
+    /// terminate the electrs process
+    pub fn kill(&mut self) -> Result<(), Error> {
+        Ok(self.process.kill()?)
+    }
 }
 
 impl Drop for ElectrsD {
     fn drop(&mut self) {
-        let _ = self.process.kill();
+        let _ = self.kill();
     }
 }
 
@@ -301,20 +306,7 @@ mod test {
 
     #[test]
     fn test_electrsd() {
-        let (bitcoind_exe, electrs_exe) = init();
-        debug!("bitcoind: {}", &bitcoind_exe);
-        debug!("electrs: {}", &electrs_exe);
-        let mut conf = bitcoind::Conf::default();
-        conf.view_stdout = log_enabled!(Level::Debug);
-        if cfg!(feature = "electrs_0_9_1") {
-            conf.p2p = P2P::Yes;
-        }
-        let bitcoind = bitcoind::BitcoinD::with_conf(&bitcoind_exe, &conf).unwrap();
-        let electrs_conf = crate::Conf {
-            view_stderr: log_enabled!(Level::Debug),
-            ..Default::default()
-        };
-        let electrsd = ElectrsD::with_conf(&electrs_exe, &bitcoind, &electrs_conf).unwrap();
+        let (electrs_exe, bitcoind, electrsd) = setup_nodes();
         let header = electrsd.client.block_headers_subscribe().unwrap();
         assert_eq!(header.height, 1);
         let address = bitcoind.client.get_new_address(None, None).unwrap();
@@ -338,6 +330,34 @@ mod test {
         assert_eq!(header.height, 101);
     }
 
+    #[test]
+    fn test_kill() {
+        let (_, bitcoind, mut electrsd) = setup_nodes();
+        let _ = bitcoind.client.ping().unwrap(); // without using bitcoind, it is dropped and all the rest fails.
+        let _ = electrsd.client.ping().unwrap();
+        assert!(electrsd.client.ping().is_ok());
+        electrsd.kill().unwrap();
+        assert!(electrsd.client.ping().is_err());
+    }
+
+    fn setup_nodes() -> (String, bitcoind::BitcoinD, ElectrsD) {
+        let (bitcoind_exe, electrs_exe) = init();
+        debug!("bitcoind: {}", &bitcoind_exe);
+        debug!("electrs: {}", &electrs_exe);
+        let mut conf = bitcoind::Conf::default();
+        conf.view_stdout = log_enabled!(Level::Debug);
+        if cfg!(feature = "electrs_0_9_1") {
+            conf.p2p = P2P::Yes;
+        }
+        let bitcoind = bitcoind::BitcoinD::with_conf(&bitcoind_exe, &conf).unwrap();
+        let electrs_conf = crate::Conf {
+            view_stderr: log_enabled!(Level::Debug),
+            ..Default::default()
+        };
+        let electrsd = ElectrsD::with_conf(&electrs_exe, &bitcoind, &electrs_conf).unwrap();
+        (electrs_exe, bitcoind, electrsd)
+    }
+
     fn init() -> (String, String) {
         let _ = env_logger::try_init();
         let bitcoind_exe_path = if let Ok(env_bitcoind_exe) = env::var("BITCOIND_EXE") {
